@@ -79,7 +79,7 @@ class BitCrcConfiguration:
         if self.width_bits % 8 == 0:
             return 8
 
-        for candidate in reversed(range(1, 16)):
+        for candidate in reversed(range(2, 16)):
             if self.width_bits % candidate == 0:
                 return candidate
 
@@ -113,26 +113,9 @@ class BitCrcRegisterBase(AbstractBitCrcRegister):
             int2ba(configuration.init_value, length=configuration.width_bits)
             & self._bitmask
         )
-
-    def __len__(self):
-        """
-        Returns the length (width) of the register.
-
-        :return: the register size/width in bits.
-        """
-        return self._config.width_bits
-
-    def __getitem__(self, index) -> bitarray:
-        """
-        Gets a single chunk of the register.
-
-        :param index: index of first bit
-        :return: number of bits (per configuration width)
-        :raises IndexError: if the index is out of bounce.
-        """
-        if index >= self.register or index < 0:
-            raise IndexError
-        return self.register[index : index + self._config.width_bits]
+        self._polynomial: bitarray = int2ba(
+            self._config.polynomial, length=self._config.width_bits
+        )
 
     def init(self):
         """
@@ -183,9 +166,6 @@ class BitCrcRegisterBase(AbstractBitCrcRegister):
         self.register = rev
         return self.register
 
-    def _is_division_possible(self):
-        return self.register >= self._topbit
-
     @property
     def register(self) -> bitarray:
         return self._register & self._bitmask
@@ -206,21 +186,14 @@ class BitCrcRegister(BitCrcRegisterBase):
         """
         See BitCrcRegisterBase._process_bits
         """
-        if len(bits) < 1:
-            return self.register
 
-        self.register ^= int2ba(
-            ba2int(bits) << (self._config.width_bits - self._config.feed_width_bits),
-            length=self._config.width_bits,
-        )
-        polynomial: bitarray = int2ba(
-            self._config.polynomial, length=self._config.width_bits
-        )
-        for _ in bits:
-            if self._is_division_possible():
-                self.register = (self.register << 1) ^ polynomial
-            else:
+        if len(bits) > 0:
+            for _ in bits:
+                op = (self.register ^ self._topbit) if _ else self.register
                 self.register <<= 1
+                if op >= self._topbit:
+                    self.register ^= self._polynomial
+
         return self.register
 
 
@@ -314,6 +287,30 @@ class BitCrcCalculator:
         return ba2int(self.calculate_checksum(data)) == expected_checksum
 
 
+@enum.unique
+class Crc7(enum.Enum):
+    ETSI_DMR = BitCrcConfiguration(
+        width_bits=7,
+        polynomial=0x27,
+        init_value=0x00,
+        final_xor_value=0x00,
+        reverse_input_bytes=False,
+        reverse_output_bytes=False,
+    )
+
+
+@enum.unique
+class Crc8(enum.Enum):
+    ETSI_DMR = BitCrcConfiguration(
+        width_bits=8,
+        polynomial=0x7,
+        init_value=0x00,
+        final_xor_value=0x00,
+        reverse_input_bytes=False,
+        reverse_output_bytes=False,
+    )
+
+
 @enum.unique
 class Crc9(enum.Enum):
     ETSI_DMR = BitCrcConfiguration(
